"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setKeywordMessage = exports.setStaticMessage = exports.setLocaleMessages = exports.ValidationError = void 0;
const staticMessageKeys = ['fallback', 'rootRequired'];
const staticMessages = {
    fallback: 'validation failed',
    rootRequired: 'value is required',
};
const keywordMessages = {
    not: () => staticMessages.fallback,
    oneOf: () => staticMessages.fallback,
    contains: () => staticMessages.fallback,
};
class ValidationError extends Error {
    constructor(errors) {
        super('');
        this.message = makeErrorMessage(errors);
        Error.captureStackTrace(this, ValidationError);
    }
}
exports.ValidationError = ValidationError;
function setLocaleMessages(messages) {
    Object.assign(staticMessages, messages.static);
    Object.assign(keywordMessages, messages.keyword);
}
exports.setLocaleMessages = setLocaleMessages;
function setStaticMessage(key, message) {
    if (typeof key !== 'string') {
        throw new Error('key is not string');
    }
    if (typeof message !== 'string') {
        throw new Error('message is not string');
    }
    if (!staticMessageKeys.includes(key)) {
        throw new Error('Invalid static message key: ' + key);
    }
    staticMessages[key] = message;
}
exports.setStaticMessage = setStaticMessage;
function setKeywordMessage(key, messageFactory) {
    if (typeof key !== 'string') {
        throw new Error('key is not string');
    }
    if (typeof messageFactory !== 'function') {
        throw new Error('messageFactory is not function');
    }
    keywordMessages[key] = messageFactory;
}
exports.setKeywordMessage = setKeywordMessage;
function makeErrorMessage(errors) {
    var _a, _b;
    if (!errors || !errors[0]) {
        return staticMessages.fallback;
    }
    const error = errors[0];
    if (error.dataPath.slice(0, 6) !== '.value') {
        if (error.keyword === 'required') {
            return staticMessages.rootRequired;
        }
        return staticMessages.fallback;
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const schema = error.parentSchema;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const params = error.params;
    const dataPath = error.dataPath.slice(6);
    // console.log(error);
    // Use custom errorMessage keyword
    if (schema.errorMessage != null) {
        let message = schema.errorMessage;
        if (typeof message === 'string') {
            return message;
        }
        message = (_a = schema.errorMessage) === null || _a === void 0 ? void 0 : _a[error.keyword];
        if (typeof message === 'string') {
            return message;
        }
        message = (_b = schema.errorMessage) === null || _b === void 0 ? void 0 : _b._;
        if (typeof message === 'string') {
            return message;
        }
    }
    // Generate error message
    const factory = keywordMessages[error.keyword];
    if (typeof factory === 'function') {
        const generated = factory(dataPath, params, schema);
        return generated || staticMessages.fallback;
    }
    return staticMessages.fallback;
}
