"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tuple = exports.array = void 0;
const base_1 = require("./base");
class ArrayShapeImpl extends base_1.BaseShapeImpl {
    constructor(schema, options) {
        super(schema, options);
    }
    minSize(size) {
        return this.produce_((draft) => {
            draft.minItems = size;
        }, undefined);
    }
    maxSize(size) {
        return this.produce_((draft) => {
            draft.maxItems = size;
        }, undefined);
    }
    size(size) {
        return this.produce_((draft) => {
            draft.minItems = size;
            draft.maxItems = size;
        }, undefined);
    }
    unique(unique = true) {
        return this.produce_((draft) => {
            draft.uniqueItems = unique;
        }, undefined);
    }
}
class TupleShapeImpl extends base_1.BaseShapeImpl {
    constructor(schema, options) {
        super(schema, options);
    }
}
/**
 * 创建一个「形状」用于描述数组，数组的元素可以是另一个「形状」的值
 * @param itemShape 描述数组元素的「形状」
 */
function array(itemShape) {
    return new ArrayShapeImpl({ type: 'array', items: itemShape.schema });
}
exports.array = array;
/**
 * 创建一个「形状」用于描述元组，元组的每个位置的「形状」按照参数顺序定义
 * @param itemShapes 元组每个元素的「形状」，按照元组元素的顺序和个数定义即可
 */
function tuple(...itemShapes) {
    return new TupleShapeImpl({
        type: 'array',
        items: itemShapes.map((item) => item.schema),
        minItems: itemShapes.length,
        maxItems: itemShapes.length,
        additionalItems: false,
    });
}
exports.tuple = tuple;
