import { Schema, SyncValidationFunction, AsyncValidationFunction } from '../util/schema.types';
import { ShapeHKT, BaseShape, ShapeOptions } from '../util/shape.types';
export declare class BaseShapeImpl<T, K extends keyof ShapeHKT<T> = 'base'> implements BaseShape<T, K> {
    schema: ShapeHKT<T>[K]['schema'];
    options?: ShapeHKT<T>[K]['options'];
    constructor(schema: Schema, options?: ShapeOptions);
    protected produce_<RT, ST extends BaseShapeImpl<T, K>>(this: ST, schemaRecipe?: (draft: ShapeHKT<T>[K]['schema']) => void, optionsRecipe?: (draft: Exclude<ShapeHKT<T>[K]['options'], undefined>) => void): ShapeHKT<RT>[K];
    optional<ST extends BaseShapeImpl<T, K>>(this: ST): ShapeHKT<T | undefined>[K];
    nullable<ST extends BaseShapeImpl<T, K>>(this: ST): ShapeHKT<T | null>[K];
    before<ST extends BaseShapeImpl<T, K>>(this: ST, schema: Schema, closest?: boolean): ShapeHKT<T>[K];
    after<ST extends BaseShapeImpl<T, K>>(this: ST, schema: Schema, closest?: boolean): ShapeHKT<T>[K];
    beforeSync<ST extends BaseShapeImpl<T, K>>(this: ST, validateFunction: SyncValidationFunction<T>, closest?: boolean): ShapeHKT<T>[K];
    afterSync<ST extends BaseShapeImpl<T, K>>(this: ST, validateFunction: SyncValidationFunction<T>, closest?: boolean): ShapeHKT<T>[K];
    beforeAsync<ST extends BaseShapeImpl<T, K>>(this: ST, validateFunction: AsyncValidationFunction<T>, closest?: boolean): ShapeHKT<T>[K];
    afterAsync<ST extends BaseShapeImpl<T, K>>(this: ST, validateFunction: AsyncValidationFunction<T>, closest?: boolean): ShapeHKT<T>[K];
    title<ST extends BaseShapeImpl<T, K>>(this: ST, title: string): ShapeHKT<T>[K];
    description<ST extends BaseShapeImpl<T, K>>(this: ST, description: string): ShapeHKT<T>[K];
    message<ST extends BaseShapeImpl<T, K>>(this: ST, message: string): ShapeHKT<T>[K];
    messages<ST extends BaseShapeImpl<T, K>>(this: ST, messages: Record<string, string>): ShapeHKT<T>[K];
    default<ST extends BaseShapeImpl<T, K>>(this: ST, value: T): ShapeHKT<Exclude<T, undefined | null>>[K];
    example<ST extends BaseShapeImpl<T, K>>(this: ST, value: T): ShapeHKT<T>[K];
    examples<ST extends BaseShapeImpl<T, K>>(this: ST, examples: Record<string, {
        value: T;
        summary?: string;
    }>): ShapeHKT<T>[K];
    validateSync(value: unknown, clone?: boolean): T;
    validateAsync(value: unknown, clone?: boolean): Promise<T>;
}
