"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseShapeImpl = void 0;
const clone_deep_1 = __importDefault(require("clone-deep"));
const validate_1 = require("../validate");
const functions_1 = require("../util/functions");
function produce(base, recipe) {
    const copied = clone_deep_1.default(base !== null && base !== void 0 ? base : {});
    const modified = recipe(copied);
    return modified || copied;
}
class BaseShapeImpl {
    constructor(schema, options) {
        this.schema = produce(schema, functions_1.noop);
        this.options = produce(options, functions_1.noop);
    }
    produce_(schemaRecipe, optionsRecipe) {
        const newInstance = Object.create(Reflect.getPrototypeOf(this));
        newInstance.schema = schemaRecipe ? produce(this.schema, schemaRecipe) : this.schema;
        newInstance.options = optionsRecipe ? produce(this.options, optionsRecipe) : this.options;
        return newInstance;
    }
    optional() {
        return this.produce_(undefined, (draft) => {
            draft.optional = true;
        });
    }
    nullable() {
        return this.produce_((draft) => {
            draft.nullable = true;
        }, undefined);
    }
    before(schema, closest = false) {
        return this.produce_((draft) => {
            var _a;
            draft.before = (_a = draft.before) !== null && _a !== void 0 ? _a : [];
            if (closest) {
                draft.before.push(schema);
            }
            else {
                draft.before.unshift(schema);
            }
        }, undefined);
    }
    after(schema, closest = false) {
        return this.produce_((draft) => {
            var _a;
            draft.after = (_a = draft.after) !== null && _a !== void 0 ? _a : [];
            if (closest) {
                draft.after.unshift(schema);
            }
            else {
                draft.after.push(schema);
            }
        }, undefined);
    }
    beforeSync(validateFunction, closest = false) {
        return this.produce_((draft) => {
            var _a;
            draft.before = (_a = draft.before) !== null && _a !== void 0 ? _a : [];
            if (closest) {
                draft.before.push({ customSync: validateFunction });
            }
            else {
                draft.before.unshift({ customSync: validateFunction });
            }
        }, undefined);
    }
    afterSync(validateFunction, closest = false) {
        return this.produce_((draft) => {
            var _a;
            draft.after = (_a = draft.after) !== null && _a !== void 0 ? _a : [];
            if (closest) {
                draft.after.unshift({ customSync: validateFunction });
            }
            else {
                draft.after.push({ customSync: validateFunction });
            }
        }, undefined);
    }
    beforeAsync(validateFunction, closest = false) {
        return this.produce_((draft) => {
            var _a;
            draft.before = (_a = draft.before) !== null && _a !== void 0 ? _a : [];
            if (closest) {
                draft.before.push({ customAsync: validateFunction });
            }
            else {
                draft.before.unshift({ customAsync: validateFunction });
            }
        }, undefined);
    }
    afterAsync(validateFunction, closest = false) {
        return this.produce_((draft) => {
            var _a;
            draft.after = (_a = draft.after) !== null && _a !== void 0 ? _a : [];
            if (closest) {
                draft.after.unshift({ customAsync: validateFunction });
            }
            else {
                draft.after.push({ customAsync: validateFunction });
            }
        }, undefined);
    }
    title(title) {
        return this.produce_((draft) => {
            draft.title = title;
        }, undefined);
    }
    description(description) {
        return this.produce_((draft) => {
            draft.description = description;
        }, undefined);
    }
    message(message) {
        return this.produce_((draft) => {
            if (typeof draft.errorMessage === 'object' && draft.errorMessage !== null) {
                draft.errorMessage._ = message;
            }
            else {
                draft.errorMessage = message;
            }
            functions_1.overwriteChildrenErrorMessage(draft, message);
        }, undefined);
    }
    messages(messages) {
        return this.produce_((draft) => {
            if (typeof draft.errorMessage === 'string') {
                draft.errorMessage = { _: draft.errorMessage, ...messages };
            }
            else {
                draft.errorMessage = { ...draft.errorMessage, ...messages };
            }
            if (messages._) {
                functions_1.overwriteChildrenErrorMessage(draft, messages._);
            }
        }, undefined);
    }
    default(value) {
        return this.produce_((draft) => {
            if (value !== undefined && value !== null) {
                draft.default = value;
            }
        }, undefined);
    }
    example(value) {
        return this.produce_((draft) => {
            draft.example = value;
        }, undefined);
    }
    examples(examples) {
        return this.produce_((draft) => {
            draft.examples = { ...draft.examples, ...examples };
        }, undefined);
    }
    validateSync(value, clone = true) {
        return validate_1.validateSync(this, value, clone);
    }
    validateAsync(value, clone = true) {
        return validate_1.validateAsync(this, value, clone);
    }
}
exports.BaseShapeImpl = BaseShapeImpl;
