"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ifThenElse = exports.ifElse = exports.ifThen = exports.allOf = exports.anyOf = exports.oneOf = exports.not = void 0;
const base_1 = require("./base");
/**
 * 创建一个「形状」用于描述不符合另一个「形状」的值
 * @param shape 不符合的那个「形状」
 */
function not(shape) {
    return new base_1.BaseShapeImpl({ not: shape.schema });
}
exports.not = not;
/**
 * 创建一个「形状」用于描述只符合一个指定「形状」的值
 * @param shapes 可传入多个「形状」，值只能符合其中一个（会根据顺序执行值类型转换）
 */
function oneOf(...shapes) {
    return new base_1.BaseShapeImpl({ oneOf: shapes.map((shape) => shape.schema) });
}
exports.oneOf = oneOf;
/**
 * 创建一个「形状」用于描述符合任意指定「形状」的值
 *
 * *值会按照「形状」的执行顺序进行转换*
 * @param shapes 可传入多个「形状」，值需要符合其中任意个形状（会根据顺序执行值类型转换）
 */
function anyOf(...shapes) {
    return new base_1.BaseShapeImpl({ anyOf: shapes.map((shape) => shape.schema) });
}
exports.anyOf = anyOf;
/**
 * 创建一个「形状」用于描述符合所有指定「形状」的值
 * @param shapes 可传入多个「形状」，值必须符合其中所有的形状（会根据顺序执行值类型转换）
 */
function allOf(...shapes) {
    return new base_1.BaseShapeImpl({ allOf: shapes.map((shape) => shape.schema) });
}
exports.allOf = allOf;
/**
 * 创建一个「形状」用于描述有条件的「形状」
 * @param condition 用作条件的「形状」，只有符合这个形状，才要求符合下面的形状
 * @param pass 用作结果的「形状」，只要符合前面的条件，就需要验证这个「形状」
 */
function ifThen(condition, pass) {
    return new base_1.BaseShapeImpl({ if: condition.schema, then: pass.schema });
}
exports.ifThen = ifThen;
/**
 * 创建一个「形状」用于描述有条件的「形状」
 * @param condition 用作条件的「形状」，只有不符合这个形状，才要求符合下面的形状
 * @param fail 用作结果的「形状」，只要不符合前面的条件，就需要验证这个「形状」
 */
function ifElse(condition, fail) {
    return new base_1.BaseShapeImpl({ if: condition.schema, else: fail.schema });
}
exports.ifElse = ifElse;
/**
 * 创建一个「形状」用于描述有条件的「形状」
 * @param condition 用作条件的「形状」，根据符合这个形状与否，要求符合下面的某一个形状
 * @param pass 用作结果的「形状」，只要符合前面的条件，就需要验证这个「形状」
 * @param fail 用作结果的「形状」，只要不符合前面的条件，就需要验证这个「形状」
 */
function ifThenElse(condition, pass, fail) {
    return new base_1.BaseShapeImpl({ if: condition.schema, then: pass.schema, else: fail.schema });
}
exports.ifThenElse = ifThenElse;
