"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.integer = exports.number = void 0;
const base_1 = require("./base");
class NumberShapeImpl extends base_1.BaseShapeImpl {
    constructor(schema, options) {
        super(schema, options);
    }
    min(value, exclusive) {
        return this.produce_((draft) => {
            if (exclusive) {
                draft.exclusiveMinimum = value;
                delete draft.minimum;
            }
            else {
                draft.minimum = value;
                delete draft.exclusiveMinimum;
            }
        }, undefined);
    }
    max(value, exclusive) {
        return this.produce_((draft) => {
            if (exclusive) {
                draft.exclusiveMaximum = value;
                delete draft.maximum;
            }
            else {
                draft.maximum = value;
                delete draft.exclusiveMaximum;
            }
        }, undefined);
    }
    range(min, max, exclusive) {
        return this.produce_((draft) => {
            if (exclusive) {
                draft.exclusiveMaximum = max;
                draft.exclusiveMinimum = min;
                delete draft.minimum;
                delete draft.maximum;
            }
            else {
                draft.minimum = min;
                draft.maximum = max;
                delete draft.exclusiveMinimum;
                delete draft.exclusiveMaximum;
            }
        }, undefined);
    }
    multipleOf(base) {
        return this.produce_((draft) => {
            draft.multipleOf = base;
        }, undefined);
    }
}
/**
 * 创建一个「形状」用于描述数字值
 */
function number() {
    return new NumberShapeImpl({ type: 'number' });
}
exports.number = number;
/**
 * 创建一个「形状」用于描述整数值
 */
function integer() {
    return new NumberShapeImpl({ type: 'integer' });
}
exports.integer = integer;
