import { ObjectShape, Shape, ShapeValue } from '../util/shape.types';
declare type ShapeObject = {
    [key: string]: Shape;
};
declare type ExtractShapeProperties<T> = {
    [K in keyof T]: ShapeValue<T[K]>;
};
declare type OptionalKeys<T> = {
    [K in keyof T]: undefined extends T[K] ? K : never;
}[keyof T];
declare type RequiredKeys<T> = {
    [K in keyof T]: undefined extends T[K] ? never : K;
}[keyof T];
declare type Flatten<T> = T extends infer U ? {
    [K in keyof U]: U[K];
} : never;
declare type FixOptional<T> = Flatten<{
    [K in RequiredKeys<T>]: T[K];
} & {
    [K in OptionalKeys<T>]?: T[K];
}>;
declare type ObjectShapeValue<T> = FixOptional<ExtractShapeProperties<T>>;
/**
 * 创建一个「形状」用于描述对象，对象的属性可以分别指定不同的「形状」
 *
 * *未指定的属性默认会在验证时去掉*
 */
export declare function object<T extends ShapeObject>(properties: T): ObjectShape<ObjectShapeValue<T>>;
/**
 * 创建一个「形状」用于描述对象，对象的属性来自两个其他的描述对象的「形状」（后者的属性会覆盖前者）
 *
 * *未指定的属性默认会在验证时去掉*
 */
export declare function merge<T, U>(base: ObjectShape<T>, extra: ObjectShape<U>): ObjectShape<Omit<T, keyof U> & U>;
export {};
