"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.merge = exports.object = void 0;
const base_1 = require("./base");
function generateSchemaProperties(properties) {
    return Object.fromEntries(Object.entries(properties).map(([key, shape]) => [key, shape.schema]));
}
function generateSchemaRequired(properties) {
    return Object.keys(properties).filter((key) => { var _a; return !((_a = properties[key].options) === null || _a === void 0 ? void 0 : _a.optional); });
}
class ObjectShapeImpl extends base_1.BaseShapeImpl {
    constructor(schema, options) {
        super(schema, options);
    }
    keepUnknown(keep = true) {
        return this.produce_((draft) => {
            draft.additionalProperties = keep;
        }, undefined);
    }
}
/**
 * 创建一个「形状」用于描述对象，对象的属性可以分别指定不同的「形状」
 *
 * *未指定的属性默认会在验证时去掉*
 */
function object(properties) {
    return new ObjectShapeImpl({
        type: 'object',
        properties: generateSchemaProperties(properties),
        required: generateSchemaRequired(properties),
        additionalProperties: false,
    });
}
exports.object = object;
/**
 * 创建一个「形状」用于描述对象，对象的属性来自两个其他的描述对象的「形状」（后者的属性会覆盖前者）
 *
 * *未指定的属性默认会在验证时去掉*
 */
function merge(base, extra) {
    var _a, _b, _c;
    return new ObjectShapeImpl({
        type: 'object',
        properties: { ...base.schema.properties, ...extra.schema.properties },
        required: [
            ...((_b = (_a = base.schema.required) === null || _a === void 0 ? void 0 : _a.filter((key) => !extra.schema.properties || !Reflect.has(extra.schema.properties, key))) !== null && _b !== void 0 ? _b : []),
            ...((_c = extra.schema.required) !== null && _c !== void 0 ? _c : []),
        ],
        additionalProperties: base.schema.additionalProperties || extra.schema.additionalProperties,
    });
}
exports.merge = merge;
