import { AnyShape, Shape, ShapeOptions } from '../util/shape.types';
import { Schema } from '../util/schema.types';
/**
 * 创建一个「形状」用于描述自定义类型的值，使用自定义的Schema来验证数据
 */
export declare function custom<T>(schema: Schema, options?: ShapeOptions): Shape<T>;
/**
 * 创建一个「形状」用于描述布尔值
 *
 * *值会先尝试转整数、再转布尔值*
 */
export declare function boolean(): AnyShape<boolean>;
/**
 * 创建一个「形状」用于描述日期时间的值
 *
 * *可以接受 Epoch毫秒数 或者 ISO8601格式的字符串*
 */
export declare function date(): AnyShape<Date>;
/**
 * 创建一个「形状」用于描述任意值
 */
export declare function any(): AnyShape<unknown>;
/**
 * 创建一个「形状」用于描述枚举值
 * @param values 枚举值的可用值列表
 */
export declare function enumerate<T>(values: T[]): AnyShape<T>;
/**
 * 创建一个「形状」用于描述固定值
 */
export declare function constant<T>(value: T): AnyShape<T>;
