"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.constant = exports.enumerate = exports.any = exports.date = exports.boolean = exports.custom = void 0;
const base_1 = require("./base");
/**
 * 创建一个「形状」用于描述自定义类型的值，使用自定义的Schema来验证数据
 */
function custom(schema, options) {
    return { schema, options };
}
exports.custom = custom;
/**
 * 创建一个「形状」用于描述布尔值
 *
 * *值会先尝试转整数、再转布尔值*
 */
function boolean() {
    return new base_1.BaseShapeImpl({ type: 'boolean' });
}
exports.boolean = boolean;
/**
 * 创建一个「形状」用于描述日期时间的值
 *
 * *可以接受 Epoch毫秒数 或者 ISO8601格式的字符串*
 */
function date() {
    return new base_1.BaseShapeImpl({ kind: 'date' });
}
exports.date = date;
/**
 * 创建一个「形状」用于描述任意值
 */
function any() {
    return new base_1.BaseShapeImpl({});
}
exports.any = any;
/**
 * 创建一个「形状」用于描述枚举值
 * @param values 枚举值的可用值列表
 */
function enumerate(values) {
    return new base_1.BaseShapeImpl({ enum: values });
}
exports.enumerate = enumerate;
/**
 * 创建一个「形状」用于描述固定值
 */
function constant(value) {
    return new base_1.BaseShapeImpl({ const: value });
}
exports.constant = constant;
