import { Shape } from './util/shape.types';
/**
 * 同步验证数据是否符合「形状」
 * - 验证通过时，返回验证后的数据
 * - 验证不通过时，抛出 ValidationError 的实例
 * - 不支持异步验证
 * @param shape 要验证的「形状」
 * @param value 要验证的数据
 * @param clone 是否在验证前深拷贝数据（默认开启）
 */
export declare function validateSync<T>(shape: Shape<T>, value: unknown, clone?: boolean): T;
/**
 * 异步验证数据是否符合「形状」
 * - 验证通过时，Promise 返回验证后的数据
 * - 验证不通过时，Promise 抛出 ValidationError 的实例
 * - 支持异步验证
 * @param shape 要验证的「形状」
 * @param value 要验证的数据
 * @param clone 是否在验证前深拷贝数据（默认开启）
 */
export declare function validateAsync<T>(shape: Shape<T>, value: unknown, clone?: boolean): Promise<T>;
